@@ -97,8 +97,10 @@ ui.modules_ga_surv_analysis <- function(id) {
 }
 
 
-server.modules_ga_surv_analysis <- function(input, output, session,
-                                            selected_database_rm_phenotype, selected_database_add_url_and_phenotype) {
+server.modules_ga_surv_analysis <- function(
+  input, output, session,
+  selected_database_rm_phenotype, selected_database_add_url_and_phenotype,
+  custom_file) {
   ns <- session$ns
 
   output$ga_data1_id <- renderUI({
@@ -114,7 +116,7 @@ server.modules_ga_surv_analysis <- function(input, output, session,
 
   id1_choices <- eventReactive(input$ga_data1_id, {
     if (!identical(input$ga_data1_id, "NONE")) {
-      if (input$ga_data1_id %in% phenotype_datasets) {
+      if (input$ga_data1_id %in% phenotype_datasets || input$ga_data1_id == "custom_phenotype_dataset") {
         # A phenotype data is selected
         return(list(
           all = "NONE",
@@ -123,7 +125,8 @@ server.modules_ga_surv_analysis <- function(input, output, session,
       } else {
         # !!Assume a dense matrix dataset is selected
         return(list(
-          all = all_preload_identifiers,
+          all = if (is.null(custom_file$fData)) all_preload_identifiers else
+            unique(c(custom_file$fData[[1]], all_preload_identifiers)),
           selected = "TP53"
         ))
       }
@@ -150,7 +153,7 @@ server.modules_ga_surv_analysis <- function(input, output, session,
     selectInput(
       inputId = ns("ga_data2_id"),
       label = "Select survival dataset:",
-      choices = c("NONE", unique(show_table$XenaDatasets[show_table$XenaDatasets %in% phenotype_datasets])),
+      choices = c("NONE", unique(show_table$XenaDatasets[show_table$XenaDatasets %in% c(phenotype_datasets, "custom_phenotype_dataset")])),
       selected = "NONE",
       multiple = FALSE
     )
@@ -174,7 +177,7 @@ server.modules_ga_surv_analysis <- function(input, output, session,
         XenaPrepare() %>%
         as.data.frame()
     } else {
-      if (length(dataset1_id)) {
+      if (length(dataset1_id) || dataset1 == "custom_phenotype_dataset") {
         data1 <- get_data_df(dataset1, dataset1_id)
       } else {
         sendSweetAlert(session,
@@ -189,11 +192,15 @@ server.modules_ga_surv_analysis <- function(input, output, session,
     dataset2 <- setdiff(input$ga_data2_id, "NONE")
     dataset2_id <- setdiff(input$ga_data2_mid, "NONE")
 
-    data2 <- XenaGenerate(subset = XenaDatasets == dataset2) %>%
-      XenaQuery() %>%
-      XenaDownload(destdir = XENA_DEST) %>%
-      XenaPrepare() %>%
-      as.data.frame()
+    if (dataset2 == "custom_phenotype_dataset") {
+      data2 <- readRDS(file.path(tempdir(), "custom_phenotype_data.rds"))
+    } else {
+      data2 <- XenaGenerate(subset = XenaDatasets == dataset2) %>%
+        XenaQuery() %>%
+        XenaDownload(destdir = XENA_DEST) %>%
+        XenaPrepare() %>%
+        as.data.frame()
+    }
     print(head(data2))
 
     if (length(dataset1) && length(dataset2)) {
@@ -558,7 +565,7 @@ server.modules_ga_surv_analysis <- function(input, output, session,
     selectInput(
       inputId = ns("ga_data_filter1_id"),
       label = "Select phenotype dataset:",
-      choices = c("NONE", unique(show_table$XenaDatasets[show_table$XenaDatasets %in% phenotype_datasets])),
+      choices = c("NONE", unique(show_table$XenaDatasets[show_table$XenaDatasets %in% c(phenotype_datasets, "custom_phenotype_dataset")])),
       selected = "NONE",
       multiple = FALSE
     )
